#Sales Application

This package offers functionalities for managing sales, including calculating prices, taxes, and discounts.

##Installation

You can install the package using:

'''bash
pip install .
"